@@ -4,6 +4,7 @@ Load datasets
 from .train_val_test_split import train_val_test_split
 from .glob_image_dir import GlobImageDir
 from .pickled_dicts import PickledDicts
+from .preprocess import PreProcess
 
 # retinal fundus images
 from .messidor import Messidor
@@ -16,3 +17,9 @@ from .qualdr import QualDR, QualDR_Grading
 
 # Chest X-Ray
 from .chexpert import CheXpert, CheXpert_Small
+
+# Microscopy
+from .BBBC038v1_microscopy import BBBC038v1
+
+# Colposcopy
+from .intel_mobileodt_cervical import IntelMobileODTCervical
