@@ -338,6 +338,12 @@ def _mode4_make_subplots(grp:pd.DataFrame, ns):
             ax.get_legend().remove()
     fig.suptitle(f'Experiment: {run_id}')
     fig.tight_layout()
+    if ns.savefig:
+        timestamp = dt.datetime.utcnow().strftime('%Y%m%dT%H%M%S')  # date plot was created.  nothing to do with timestamp column.
+        savefig_with_symlink(
+            fig,
+            f'{ns.mode4_savefig_dir}/archive/{run_id}_mode4_{timestamp}.png',
+            f'{ns.mode4_savefig_dir}/{run_id}_mode4_latest.png')
 
 
 def mode_4_plots(ns):
@@ -387,6 +393,7 @@ def bap():
     A('--mode1-savefig-dir', default='./results/plots/mode1', help=' ')
     A('--mode2-savefig-dir', default='./results/plots/mode2', help=' ')
     A('--mode3-savefig-dir', default='./results/plots/mode3', help=' ')
+    A('--mode4-savefig-dir', default='./results/plots/mode4', help=' ')
     A('--mode3-ci', type=float,
       help='confidence interval for error bars.  If 0, also shows all lines individually')
     A('--mode4-groupby', default="(Train|Val|Test) (.*):2", help=dedent('''\
